
# Version 1: 29 August 2019

# This script is called by the main script "Forest_Carbon_MC.R."

###############################################################################################################
## FUNCTION NAME: Saplings.R
## INPUTS:  Live and dead sapling data for plot being analyzed
## OUTPUTS: Pounds of carbon per acre estimates for live and dead saplings on this plot
###############################################################################################################

# If a particular plot has no saplings, skip it
if (nrow(saps)>0){
       
    
  #####################################################
  # Step 1. Calculate Jenkins biomass by component 
  #####################################################
  
  # Step 1a. Calculate foliage and root ratios
  ratioRoot<- cbind(saps[,1:2],ratioRoot=exp(rootb1[match(saps$ID_ratio_coeff,rootb1[,1]),-1]+(rootb2[match(saps$ID_ratio_coeff,rootb2[,1]),-1]/(saps$DIA*2.54))))
  ratioFoliage<- cbind(saps[,1:2],ratioFoliage=exp(folgb1[match(saps$ID_ratio_coeff,folgb1[,1]),-1]+(folgb2[match(saps$ID_ratio_coeff,folgb2[,1]),-1]/(saps$DIA*2.54))))


  # Step 1b. Separate TAB into its components    
  rootBio<- as.data.frame(ratioRoot)
  rootBio<- cbind(rootBio[,1:2],rootBio[,-(1:2)]*tab[match(rootBio[,1],tab[,1]),-(1:2)])
    
  foliageBio<- as.data.frame(ratioFoliage)
  foliageBio<- cbind(foliageBio[,1:2],foliageBio[,-(1:2)]*tab[match(foliageBio[,1],tab[,1]),-(1:2)])

  rm(ratioRoot, ratioFoliage)
   
   
  
  #####################################################
  # Step 2. Calculate above- and below-ground carbon
  #####################################################
  
  # Aboveground carbon
  sapsAGC<- cbind(saps[,1:3], AGC=0.5*sapAdj[match(saps$ID_JENKINS_SAPLING_ADJUSTMENT,sapAdj[,1]),-1]*(tab[match(saps$ID_TREE,tab[,1]),-(1:2)]-foliageBio[match(saps$ID_TREE,foliageBio[,1]),-(1:2)]))

  # Belowground carbon
  sapsBGC<- cbind(saps[,1:3], BGC=0.5*sapAdj[match(saps$ID_JENKINS_SAPLING_ADJUSTMENT,sapAdj[,1]),-1]*rootBio[match(saps$ID_TREE,rootBio[,1]),-(1:2)])
  
  sapsAGC<- sapsAGC[order(sapsAGC$ID_TREE),]
  sapsBGC<- sapsBGC[order(sapsBGC$ID_TREE),]

  # Combine AGC and BGC and multiply by applicable TPA_UNADJ value to convert to pounds C per acre represented by that tree
  sapsC<- cbind(sapsAGC[,1:3], sapsAGC[,-(1:3)]+sapsBGC[,-(1:3)])
  sapsC[,-(1:3)]<- sapsC[,-(1:3)]*tpaSap
  
  rm(sapsAGC, sapsBGC)
  
}


