
# Version 1: 29 August 2019

# This script is called by the main script "Forest_Carbon_MC.R."

###############################################################################################################
## FUNCTION NAME: Woodland_Trees.R
## INPUTS: Data for woodland trees (with diameter greater than or equal to 5.0 inches) on plot being analyzed
## OUTPUTS: Pounds of carbon per acre estimates for live and dead woodland trees on this plot
###############################################################################################################

# If a particular plot has no woodland trees, skip it
if (nrow(woodland)>0){


  #####################################################
  # Step 1. Calculate bole biomass - DRYBIO_BOL
  #####################################################
  
  # Step 1a. Calculate bole-wood gross cubic-foot volume
  V1<- woodland$DIA^2*woodland$HT*0.001
  compare<- V1<=b5[match(woodland$ID_VOLCOEFF,b5[,1]),-1]
  VOLtemp1<- as.matrix(b0[match(woodland$ID_VOLCOEFF,b0[,1]),-1]+b1[match(woodland$ID_VOLCOEFF,b1[,1]),-1]*V1+b2[match(woodland$ID_VOLCOEFF,b2[,1]),-1]*V1^2)
  VOLtemp2<- as.matrix(b3[match(woodland$ID_VOLCOEFF,b3[,1]),-1]+b1[match(woodland$ID_VOLCOEFF,b1[,1]),-1]*V1-b4[match(woodland$ID_VOLCOEFF,b4[,1]),-1]/V1)
  
  VOLtemp1<- ifelse(compare,VOLtemp1,VOLtemp2)
  VOLtemp1<- ifelse(VOLtemp1<=0,0.1,VOLtemp1)
  VOLCFGRSw<- as.data.frame(cbind(woodland[,c(1:3,5:7)],VOLCFGRS=VOLtemp1))
  
  # Step 1b. Calculate bole-wood sound cubic-foot volume by subtracting rotten and missing parts (cull) from gross volume
  VOLCFSNDw<- cbind(VOLCFGRSw[,1:6],VOLCFSND=VOLCFGRSw[,7:ncol(VOLCFGRSw)]*(1-woodland$CULL_ADJ/100))
  
  # Step 1c. Calculate bole biomass
  DRYBIO_BOLEw<- cbind(VOLCFSNDw[,1:3], DRYBIO_BOLE=(VOLCFSNDw[,-(1:6)]*barkVolPct[match(VOLCFSNDw[,6],barkVolPct[,1]),-1]*0.01*barkSPGR[match(VOLCFSNDw[,5],barkSPGR[,1]),-1]*62.4)+(VOLCFSNDw[,-(1:6)]-(VOLCFSNDw[,-(1:6)]*barkVolPct[match(VOLCFSNDw[,6],barkVolPct[,1]),-1]*0.01))*woodSPGR[match(VOLCFSNDw[,4],woodSPGR[,1]),-1]*62.4)
  
  # Adjustment for dead trees
  drfBole<- cbind(woodland$ID_TREE,drf[match(woodland$ID_DRF, drf[,1]),-1]*slaBole[match(woodland$ID_SLA,slaBole[,1]),-1])
  drfBark<- cbind(woodland$ID_TREE, drf[match(woodland$ID_DRF, drf[,1]),-1]*slaBark[match(woodland$ID_SLA,slaBark[,1]),-1])
  DRYBIO_BOLE_DEADw<- cbind(VOLCFSNDw[,1:3], DRYBIO_BOLE=(VOLCFSNDw[,-(1:6)]*barkVolPct[match(VOLCFSNDw[,6],barkVolPct[,1]),-1]*0.01*barkSPGR[match(VOLCFSNDw[,5],barkSPGR[,1]),-1]*62.4*drfBark[match(VOLCFSNDw[,1],drfBark[,1]),-1])+(VOLCFSNDw[,-(1:6)]-(VOLCFSNDw[,-(1:6)]*barkVolPct[match(VOLCFSNDw[,6],barkVolPct[,1]),-1]*0.01))*woodSPGR[match(VOLCFSNDw[,4],woodSPGR[,1]),-1]*62.4*drfBole[match(VOLCFSNDw[,1],drfBole[,1]),-1])
  colnames(DRYBIO_BOLE_DEADw)<- colnames(DRYBIO_BOLEw)
  
  DRYBIO_BOLEw<- rbind(DRYBIO_BOLEw[DRYBIO_BOLEw$ID_CATEGORY!=7,],DRYBIO_BOLE_DEADw[DRYBIO_BOLEw$ID_CATEGORY==7,])
  DRYBIO_BOLEw<- DRYBIO_BOLEw[order(DRYBIO_BOLEw$ID_TREE),]
  
  rm(V1,compare,VOLCFGRSw,VOLCFSNDw,DRYBIO_BOLE_DEADw,drfBark,drfBole, VOLtemp1,VOLtemp2)
  
  
  
  

  #####################################################
  # Step 2. Calculate Jenkins biomass by component 
  #####################################################
      
  # Step 2a. Calculate foliage and root ratios
  ratioRoot<- cbind(woodland[,1:2],ratioRoot=exp(rootb1[match(woodland$ID_ratio_coeff,rootb1[,1]),-1]+(rootb2[match(woodland$ID_ratio_coeff,rootb2[,1]),-1]/(woodland$DIA*2.54))))
  ratioFoliage<- cbind(woodland[,1:2],ratioFoliage=exp(folgb1[match(woodland$ID_ratio_coeff,folgb1[,1]),-1]+(folgb2[match(woodland$ID_ratio_coeff,folgb2[,1]),-1]/(woodland$DIA*2.54))))


  # Step 2b. Separate TAB into its components
    
  rootBio<- as.data.frame(ratioRoot)
  rootBio<- cbind(rootBio[,1:2],rootBio[,-(1:2)]*tab[match(rootBio[,1],tab[,1]),-(1:2)])
    
  foliageBio<- as.data.frame(ratioFoliage)
  foliageBio<- cbind(foliageBio[,1:2],foliageBio[,-(1:2)]*tab[match(foliageBio[,1],tab[,1]),-(1:2)])

rm(ratioRoot, ratioFoliage)

  
  
  
 
  #####################################################
  # Step 3. Calculate CRM adjustment factor - CRMadj
  #####################################################
  
  # Step 3a. Calculate CRM adjustment factor
  CRMadjw<- cbind(DRYBIO_BOLEw[,1:3], CRMadj=DRYBIO_BOLEw[,-(1:3)]/(tab[match(DRYBIO_BOLEw[,1],tab[,1]),-(1:2)]-foliageBio[match(DRYBIO_BOLEw[,1],foliageBio[,1]),-(1:2)]))
 
    
  
  
  #####################################################
  # Step 4. Calculate above- and below-ground carbon
  #####################################################
  
  woodlandAGC<- cbind(DRYBIO_BOLEw[,1:3], AGC=0.5*DRYBIO_BOLEw[,-(1:3)])    
  woodlandAGC<- woodlandAGC[order(woodlandAGC$ID_TREE),]    
  woodlandBGC<- cbind(woodland[,1:3],BGC=0.5*CRMadjw[match(woodland$ID_TREE,CRMadjw[,1]),-(1:3)]*rootBio[match(woodland$ID_TREE,rootBio[,1]),-(1:2)])
  
  # Step 6b. Adjustment for dead trees
  slaBGwoodland<- cbind(woodland$ID_TREE,slaBG[match(woodland$ID_SLA, slaBG[,1]),-1])
  woodlandBGC_DEAD<- cbind(woodlandBGC[,1:3], BGC=woodlandBGC[,-(1:3)]*slaBGwoodland[,-1])
  colnames(woodlandBGC_DEAD)<- colnames(woodlandBGC)
  
  woodlandBGC<- rbind(woodlandBGC[woodlandBGC$ID_CATEGORY!=7,],woodlandBGC_DEAD[woodlandBGC_DEAD$ID_CATEGORY==7,])
  woodlandBGC<- woodlandBGC[order(woodlandBGC$ID_TREE),]
   
  # Step 6c. combine AGC and BGC and multiply by applicable TPA_UNADJ value to convert to pounds C per acre represented by that tree
  woodlandC<- cbind(woodlandAGC[,1:3], woodlandAGC[,-(1:3)]+woodlandBGC[,-(1:3)])
  woodlandC[,-(1:3)]<- woodlandC[,-(1:3)]*tpaTree
  
  rm(slaBGwoodland, woodlandBGC_DEAD, woodlandAGC, woodlandBGC, DRYBIO_BOLEw, CRMadjw)


}



